@@ -10,10 +10,12 @@ from mindsdb_sql.parser.dialects.mindsdb.latest import Latest
 from mindsdb_sql.exceptions import ParsingException
 from mindsdb_sql.parser.dialects.mindsdb.lexer import MindsDBLexer
 from mindsdb_sql.parser.dialects.mindsdb.retrain_predictor import RetrainPredictor
+from mindsdb_sql.parser.logger import ParserLogger
 from mindsdb_sql.utils import ensure_select_keyword_order, JoinType
 
 
 class MindsDBParser(Parser):
+    log = ParserLogger()
     tokens = MindsDBLexer.tokens
 
     precedence = (
@@ -76,11 +78,15 @@ class MindsDBParser(Parser):
     def set(self, p):
         return Set(category=p.AUTOCOMMIT)
 
+    @_('SET expr')
+    def set(self, p):
+        return Set(arg=p.expr)
+
     @_('SET ID identifier')
     def set(self, p):
-        if not p.ID == 'names':
-            raise ParsingException(f'Excepted "names"')
-        return Set(category=p.ID, arg=p.identifier)
+        if not p.ID.lower() == 'names':
+            raise ParsingException(f'Expected "SET names", got "SET {p.ID}"')
+        return Set(category=p.ID.lower(), arg=p.identifier)
 
     # Show
 
@@ -121,8 +127,10 @@ class MindsDBParser(Parser):
        'WARNINGS',
        'ENGINES',
        'CHARSET',
+       'CHARACTER SET',
        'COLLATION',
        'TABLE STATUS',
+       'STATUS',
        # Mindsdb specific
        'VIEWS',
        'STREAMS',
@@ -166,7 +174,8 @@ class MindsDBParser(Parser):
         return RetrainPredictor(p.identifier)
 
     # DROP PREDICTOR
-    @_('DROP PREDICTOR identifier')
+    @_('DROP PREDICTOR identifier',
+       'DROP TABLE identifier')
     def drop_predictor(self, p):
         return DropPredictor(p.identifier)
 
@@ -176,14 +185,10 @@ class MindsDBParser(Parser):
         return DropIntegration(p.identifier)
 
     # CREATE PREDICTOR
-    @_('create_predictor USING STRING')
+    @_('create_predictor USING JSON')
     def create_predictor(self, p):
-        try:
-            using = json.loads(p.STRING)
-            p.create_predictor.using = using
-            return p.create_predictor
-        except ValueError as err:
-            raise ParsingException(f'Predictor USING must be a valid json, got error: {str(err)}')
+        p.create_predictor.using = p.JSON
+        return p.create_predictor
 
     @_('create_predictor HORIZON INTEGER')
     def create_predictor(self, p):
@@ -209,28 +214,31 @@ class MindsDBParser(Parser):
         p.create_predictor.order_by = p.ordering_terms
         return p.create_predictor
 
-    @_('CREATE PREDICTOR ID FROM ID WITH LPAREN STRING RPAREN AS ID PREDICT result_columns')
+    @_('CREATE PREDICTOR identifier FROM identifier WITH STRING optional_data_source_name PREDICT result_columns')
     def create_predictor(self, p):
         return CreatePredictor(
-            name=p.ID0,
-            integration_name=p.ID1,
+            name=p.identifier0,
+            integration_name=p.identifier1,
             query=p.STRING,
-            datasource_name=p.ID2,
-            targets=p.result_columns
+            datasource_name=p.optional_data_source_name,
+            targets=p.result_columns,
         )
 
-    # CREATE INTEGRATION
-    @_('CREATE INTEGRATION ID WITH ENGINE EQUALS STRING COMMA PARAMETERS EQUALS STRING',
-       'CREATE DATASOURCE ID WITH ENGINE EQUALS STRING COMMA PARAMETERS EQUALS STRING')
-    def create_integration(self, p):
-        try:
-            parameters = json.loads(p.STRING1)
-            return CreateIntegration(name=p.ID,
-                                     engine=p.STRING0,
-                                     parameters=parameters)
-        except ValueError as err:
-            raise ParsingException(f'Integration args must be a valid json, got error: {str(err)}')
+    @_('AS identifier')
+    def optional_data_source_name(self, p):
+        return p.identifier
 
+    @_('empty')
+    def optional_data_source_name(self, p):
+        pass
+
+    # CREATE INTEGRATION
+    @_('CREATE INTEGRATION ID WITH ENGINE EQUALS STRING COMMA PARAMETERS EQUALS JSON',
+       'CREATE DATASOURCE ID WITH ENGINE EQUALS STRING COMMA PARAMETERS EQUALS JSON')
+    def create_integration(self, p):
+        return CreateIntegration(name=p.ID,
+                                 engine=p.STRING,
+                                 parameters=p.JSON)
 
     # UNION / UNION ALL
     @_('select UNION select')
@@ -380,14 +388,6 @@ class MindsDBParser(Parser):
         select.where = where_expr
         return select
 
-    # Mindsdb special case
-    @_('select FROM PREDICTORS')
-    def select(self, p):
-        select = p.select
-        ensure_select_keyword_order(select, 'FROM')
-        select.from_table = Identifier(p.PREDICTORS)
-        return select
-
     # Special cases for keyword-like identifiers
     @_('select FROM TABLES')
     def select(self, p):
@@ -643,9 +643,21 @@ class MindsDBParser(Parser):
     def constant(self, p):
         return Constant(value=str(p.STRING))
 
-    @_('ID')
+    @_('identifier DOT identifier')
     def identifier(self, p):
-        value = p.ID
+        p.identifier0.parts += p.identifier1.parts
+        return p.identifier0
+
+    @_('ID',
+       'CHARSET',
+       'TABLES',
+       # Mindsdb specific
+       'STATUS',
+       'PREDICT',
+       'PREDICTOR',
+       'PREDICTORS')
+    def identifier(self, p):
+        value = p[0]
         return Identifier.from_path_str(value)
 
     @_('PARAMETER')
