@@ -1,12 +1,15 @@
+from mindsdb_sql.parser.logger import ParserLogger
 from mindsdb_sql.parser.parser import SQLParser
 from mindsdb_sql.parser.ast import *
 from mindsdb_sql.parser.dialects.mysql.lexer import MySQLLexer
 from mindsdb_sql.parser.dialects.mysql.variable import Variable
+from mindsdb_sql.parser.dialects.mysql.show_index import ShowIndex
 from mindsdb_sql.exceptions import ParsingException
 from mindsdb_sql.utils import ensure_select_keyword_order, JoinType
 
 
 class MySQLParser(SQLParser):
+    log = ParserLogger()
     tokens = MySQLLexer.tokens
 
     precedence = (
@@ -59,18 +62,21 @@ class MySQLParser(SQLParser):
 
     # Set
 
+    @_('SET expr')
+    def set(self, p):
+        return Set(arg=p.expr)
+
     @_('SET AUTOCOMMIT')
     def set(self, p):
         return Set(category=p.AUTOCOMMIT)
 
     @_('SET ID identifier')
     def set(self, p):
-        if not p.ID == 'names':
-            raise ParsingException(f'Excepted "names"')
-        return Set(category=p.ID, arg=p.identifier)
+        if not p.ID.lower() == 'names':
+            raise ParsingException(f'Expected "SET names", got "SET {p.ID}"')
+        return Set(category=p.ID.lower(), arg=p.identifier)
 
     # Show
-
     @_('SHOW show_category show_condition_or_nothing')
     def show(self, p):
         condition = p.show_condition_or_nothing['condition'] if p.show_condition_or_nothing else None
@@ -79,6 +85,15 @@ class MySQLParser(SQLParser):
                     condition=condition,
                     expression=expression)
 
+    @_('SHOW INDEX FROM identifier FROM identifier')
+    def show(self, p):
+        return ShowIndex(table=p.identifier0,
+                         db=p.identifier1)
+
+    @_('SHOW INDEX FROM identifier')
+    def show(self, p):
+        return ShowIndex(table=p.identifier)
+
     @_('show_condition_token expr',
        'empty')
     def show_condition_or_nothing(self, p):
@@ -103,13 +118,14 @@ class MySQLParser(SQLParser):
        'GLOBAL VARIABLES',
        'PROCEDURE STATUS',
        'FUNCTION STATUS',
-       'INDEX',
        'CREATE TABLE',
        'WARNINGS',
        'ENGINES',
        'CHARSET',
+       'CHARACTER SET',
        'COLLATION',
-       'TABLE STATUS')
+       'TABLE STATUS',
+       'STATUS')
     def show_category(self, p):
         return ' '.join([x for x in p])
 
@@ -520,9 +536,16 @@ class MySQLParser(SQLParser):
     def constant(self, p):
         return Constant(value=str(p.STRING))
 
-    @_('ID')
+    @_('identifier DOT identifier')
     def identifier(self, p):
-        value = p.ID
+        p.identifier0.parts += p.identifier1.parts
+        return p.identifier0
+
+    @_('ID',
+       'CHARSET',
+       'TABLES')
+    def identifier(self, p):
+        value = p[0]
         return Identifier.from_path_str(value)
 
     @_('PARAMETER')
